@@ -539,10 +539,10 @@ is_banned_list(struct Channel *chptr, rb_dlink_list *list,
 	       struct Client *who, struct membership *msptr,
 	       const char *s, const char *s2, const char **forward)
 {
-	char src_host[NICKLEN + USERLEN + HOSTLEN + 6];
-	char src_iphost[NICKLEN + USERLEN + HOSTLEN + 6];
-	char src_althost[NICKLEN + USERLEN + HOSTLEN + 6];
-	char src_ip4host[NICKLEN + USERLEN + HOSTLEN + 6];
+	char src_host[NAMELEN + USERLEN + HOSTLEN + 6];
+	char src_iphost[NAMELEN + USERLEN + HOSTLEN + 6];
+	char src_althost[NAMELEN + USERLEN + HOSTLEN + 6];
+	char src_ip4host[NAMELEN + USERLEN + HOSTLEN + 6];
 	char *s3 = NULL;
 	char *s4 = NULL;
 	struct sockaddr_in ip4;
@@ -722,9 +722,9 @@ can_join(struct Client *source_p, struct Channel *chptr, const char *key, const
 	rb_dlink_node *invite = NULL;
 	rb_dlink_node *ptr;
 	struct Ban *invex = NULL;
-	char src_host[NICKLEN + USERLEN + HOSTLEN + 6];
-	char src_iphost[NICKLEN + USERLEN + HOSTLEN + 6];
-	char src_althost[NICKLEN + USERLEN + HOSTLEN + 6];
+	char src_host[NAMELEN + USERLEN + HOSTLEN + 6];
+	char src_iphost[NAMELEN + USERLEN + HOSTLEN + 6];
+	char src_althost[NAMELEN + USERLEN + HOSTLEN + 6];
 	int use_althost = 0;
 	int i = 0;
 	hook_data_channel moduledata;
@@ -964,8 +964,8 @@ find_bannickchange_channel(struct Client *client_p)
 	struct Channel *chptr;
 	struct membership *msptr;
 	rb_dlink_node *ptr;
-	char src_host[NICKLEN + USERLEN + HOSTLEN + 6];
-	char src_iphost[NICKLEN + USERLEN + HOSTLEN + 6];
+	char src_host[NAMELEN + USERLEN + HOSTLEN + 6];
+	char src_iphost[NAMELEN + USERLEN + HOSTLEN + 6];
 
 	if (!MyClient(client_p))
 		return NULL;
