@@ -76,7 +76,7 @@ parse_netmask(const char *text, struct rb_sockaddr_storage *naddr, int *nb)
 				return HM_HOST;
 		} else
 			*b = 128;
-		if(rb_inet_pton_sock(ip, (struct sockaddr *)addr) > 0)
+		if(rb_inet_pton_sock(ip, addr) > 0)
 			return HM_IPV6;
 		else
 			return HM_HOST;
@@ -94,7 +94,7 @@ parse_netmask(const char *text, struct rb_sockaddr_storage *naddr, int *nb)
 				return HM_HOST;
 		} else
 			*b = 32;
-		if(rb_inet_pton_sock(ip, (struct sockaddr *)addr) > 0)
+		if(rb_inet_pton_sock(ip, addr) > 0)
 			return HM_IPV4;
 		else
 			return HM_HOST;
@@ -198,6 +198,9 @@ get_mask_hash(const char *text)
 
 /* struct ConfItem* find_conf_by_address(const char*, struct rb_sockaddr_storage*,
  *         int type, int fam, const char *username)
+ *
+ * This process needs to be kept in sync with check_one_kline().
+ *
  * Input: The hostname, the address, the type of mask to find, the address
  *        family, the username.
  * Output: The matching value with the highest precedence.
