@@ -707,7 +707,6 @@ set_default_conf(void)
 	ConfigFileEntry.client_exit = true;
 	ConfigFileEntry.dline_with_reason = true;
 	ConfigFileEntry.kline_with_reason = true;
-	ConfigFileEntry.kline_delay = 0;
 	ConfigFileEntry.warn_no_nline = true;
 	ConfigFileEntry.non_redundant_klines = true;
 	ConfigFileEntry.stats_e_disabled = false;
@@ -1261,7 +1260,7 @@ char *
 get_oper_name(struct Client *client_p)
 {
 	/* +5 for !,@,{,} and null */
-	static char buffer[NICKLEN + USERLEN + HOSTLEN + HOSTLEN + 5];
+	static char buffer[NAMELEN + USERLEN + HOSTLEN + HOSTLEN + 5];
 
 	if(MyOper(client_p))
 	{
