@@ -414,13 +414,13 @@ register_local_user(struct Client *client_p, struct Client *source_p)
 	/* Apply nick override */
 	if(*source_p->preClient->spoofnick)
 	{
-		char note[NICKLEN + 10];
+		char note[NAMELEN + 10];
 
 		del_from_client_hash(source_p->name, source_p);
 		rb_strlcpy(source_p->name, source_p->preClient->spoofnick, NICKLEN + 1);
 		add_to_client_hash(source_p->name, source_p);
 
-		snprintf(note, NICKLEN + 10, "Nick: %s", source_p->name);
+		snprintf(note, sizeof(note), "Nick: %s", source_p->name);
 		rb_note(source_p->localClient->F, note);
 	}
 
@@ -1484,14 +1484,17 @@ construct_umodebuf(void)
 			if (user_modes[i] == 0)
 			{
 				orphaned_umodes |= prev_user_modes[i];
-				user_modes[i] = prev_user_modes[i];
+				sendto_realops_snomask(SNO_DEBUG, L_ALL, "Umode +%c is now orphaned", i);
 			}
 			else
+			{
 				orphaned_umodes &= ~prev_user_modes[i];
+				sendto_realops_snomask(SNO_DEBUG, L_ALL, "Orphaned umode +%c is picked up by module", i);
+			}
+			user_modes[i] = prev_user_modes[i];
 		}
 		else
 			prev_user_modes[i] = user_modes[i];
-
 		if (user_modes[i])
 			*ptr++ = (char) i;
 	}
